@@ -1,4 +1,4 @@
-/* Copyright (C) 2003  Free Software Foundation.
+/* Copyright (C) 2003, 2005  Free Software Foundation.
 
    Verify that the `const' function attribute is applied to various
    builtins and that these functions are optimized away by the
@@ -336,14 +336,16 @@ FPTEST3            (fma)
 FPTEST2            (fmax)
 FPTEST2            (fmin)
 FPTEST2            (fmod)
+FPTEST1            (gamma)
 BUILTIN_FPTEST0    (huge_val)
 FPTEST2            (hypot)
 FPTEST1T           (ilogb, int)
-BUILTIN_FPTEST0    (inf) /* { dg-warning "does not support infinity" "INF unsupported" { target vax-*-* c4x-*-* pdp11-*-* } } */
+BUILTIN_FPTEST0    (inf)
 FPTEST1            (j0)
 FPTEST1            (j1)
 FPTEST2ARG1        (jn, int)
 FPTEST2ARG2        (ldexp, int)
+FPTEST1            (lgamma)
 FPTEST1T           (llrint, long long)
 FPTEST1T           (llround, long long)
 FPTEST1            (log)
@@ -391,7 +393,7 @@ CPTEST1 (ccos)
 CPTEST1 (ccosh)
 CPTEST1 (cexp)
 CPTEST1R (cimag)
-/*CPTEST1 (clog)*/
+CPTEST1 (clog)
 CPTEST1 (conj)
 CPTEST2 (cpow)
 CPTEST1 (cproj)
